Struct secure_session::middleware::SessionConfig [] [src]

pub struct SessionConfig { /* fields omitted */ }

Configuration of how sessions and session cookies are created and validated.

Methods

impl SessionConfig
[src]

[src]

Create a new builder that is initialized with the default configuration.